@@ -32,7 +32,7 @@ Text::Xslate::Syntax::Metakolon - The same as Kolon but using [% ... %] tags
 =head1 DESCRIPTION
 
 Metakolon is the same as Kolon except for using C<< [% ... %] >> tags and
-C<< % ... >> line code, instead of C<< <: ... :> >> and C<< : ... >>.
+C<< %% ... >> line code, instead of C<< <: ... :> >> and C<< : ... >>.
 
 This may be useful when you want to produce Xslate templates by itself.
 
